@@ -32,7 +32,7 @@ def parse_ahb_expression_to_single_requirement_indicator_expressions(ahb_express
     PREFIX_OPERATOR: "X"i | "O"i | "U"i
     MODAL_MARK: /M(uss)?|S(oll)?|K(ann)?/i
     // Matches if it looks like a condition expression, but does not yet check if it is a syntactically valid one:
-    CONDITION_EXPRESSION: /(?!\BU\B)[\[\]\(\)U∧O∨X⊻\d\sP\.]+/i
+    CONDITION_EXPRESSION: /(?!\BU\B)[\[\]\(\)U∧O∨X⊻\d\sP\.UB]+/i
     """
     # Regarding the negative lookahead in the condition expression regex see examples https://regex101.com/r/6fFHD4/1
     # and CTRL+F for "Mus[2]" in the unittest that fails if you remove the lookahead.
